@@ -42,6 +42,8 @@ job3.minute.every(1)
 
 sys.stdout.write(str(cron.render()))
 
+job3.enable(False)
+
 for job4 in cron.find_command('echo'):
     sys.stdout.write(job4)
 
@@ -60,7 +62,7 @@ import os, re, sys
 import tempfile
 
 __pkgname__ = 'python-crontab'
-__version__ = '1.3'
+__version__ = '1.3.2'
 
 CRONCMD = "/usr/bin/crontab"
 ITEMREX = re.compile('^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)' +
@@ -181,11 +183,6 @@ class CronTab(object):
         """Render this crontab as it would be in the crontab."""
         crons = []
         for cron in self.lines:
-            if type(cron) == CronItem and not cron.is_valid():
-                crons.append("# " + unicode(cron))
-                sys.stderr.write(
-                    "Ignoring invalid crontab line `%s`\n" % str(cron))
-                continue
             crons.append(unicode(cron))
         result = '\n'.join(crons)
         if result and result[-1] not in [ '\n', '\r' ]:
@@ -258,19 +255,23 @@ class CronItem(object):
     """
     def __init__(self, line=None, command='', meta='', compat=False):
         self.valid = False
+        self.enabled = True
         self.slices  = []
         self.special = False
         self.compat  = compat
         self.set_slices()
         self._meta   = meta
         if line:
-            self.parse(line)
+            self.parse(line.strip())
         elif command:
             self.command = CronCommand(unicode(command))
             self.valid = True
 
     def parse(self, line):
         """Parse a cron line string and save the info as the objects."""
+        if line[0] == '#':
+            self.enabled = False
+            line = line[1:].strip()
         result = ITEMREX.findall(line)
         if result:
             o_value = result[0]
@@ -301,12 +302,22 @@ class CronItem(object):
                 CronSlice(compat=self.compat, value=o_value[i_value],
                     **S_INFO[i_value]))
 
+    def enable(self, enabled=True):
+        """Set if this cron job is enabled or not"""
+        if enabled in [True, False]:
+            self.enabled = enabled
+        return self.enabled
+
+    def is_enabled(self):
+        """Return true if this job is enabled (not commented out)"""
+        return self.enabled
+
     def is_valid(self):
-        """Return true if this slice set is valid"""
+        """Return true if this job is valid"""
         return self.valid
 
     def render(self):
-        """Render this set slice to a string"""
+        """Render this set cron-job to a string"""
         time = ''
         if not self.special:
             slices = []
@@ -322,6 +333,8 @@ class CronItem(object):
         result = "%s %s" % (time, unicode(self.command))
         if self.meta():
             result += " # " + self.meta()
+        if not self.enabled:
+            result = "# " + result
         return result
 
     def meta(self, value=None):
@@ -375,6 +388,9 @@ class CronItem(object):
         return self.__unicode__()
 
     def __unicode__(self):
+        if not self.is_valid():
+            sys.stderr.write("Ignoring invalid crontab line\n")
+            return "# " + unicode(self.render())
         return self.render()
 
 
